Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(946)

Unified Diff: appengine/findit/model/wf_culprit.py

Issue 2104113002: [Findit] Add settings for actions after culprits or suspects are identified. (Closed) Base URL: https://chromium.googlesource.com/infra/infra.git@group_same_failures
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: appengine/findit/model/wf_culprit.py
diff --git a/appengine/findit/model/wf_culprit.py b/appengine/findit/model/wf_culprit.py
index f40882b5a3bd96388897eeafb5bc0db306017cee..182094f27a3961e38f797242e4051e20c6164531 100644
--- a/appengine/findit/model/wf_culprit.py
+++ b/appengine/findit/model/wf_culprit.py
@@ -22,7 +22,8 @@ class WfCulprit(ndb.Model):
# When the code-review of this culprit was notified.
cr_notification_time = ndb.DateTimeProperty(indexed=True)
# The status of code-review notification: None, RUNNING, COMPLETED, ERROR.
cr_notification_status = ndb.IntegerProperty(indexed=True)
# The list of builds in which the culprit caused some breakage.
@@ -34,7 +35,8 @@ class WfCulprit(ndb.Model):
@property
def cr_notification_processed(self):
- return self.cr_notification_status in (status.COMPLETED, status.RUNNING)
+ return self.cr_notification_status in (
+ status.COMPLETED, status.RUNNING, status.SKIPPED)
@property
def cr_notified(self):

Powered by Google App Engine
@@ -22,7 +22,8 @@ class WfCulprit(ndb.Model):
# When the code-review of this culprit was notified.
cr_notification_time = ndb.DateTimeProperty(indexed=True)
- # The status of code-review notification: None, RUNNING, COMPLETED, ERROR.
+ # The status of code-review notification:
+ # None, RUNNING, COMPLETED, ERROR, SKIPPED.
cr_notification_status = ndb.IntegerProperty(indexed=True)
# The list of builds in which the culprit caused some breakage.
This is Rietveld 408576698